# PyParticles : Particles simulation in python
# Copyright (C) 2012  Simone Riva
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import pyparticles.animation.test_animation as tt

def test( ty ):
    """
    testing procedures
    
    ty: test name
    """
    if ty == "fall":
        tst = tt.TestAnimation()
    elif ty == "harmonic" :
        tst = tt.TestAnimationHarmonic()
    elif ty == "dharmonic" :
        tst = tt.TestAnimationDampedHarmonic()
        
    tst.build_animation()
    tst.start()